#
# spec file for package libacars
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2019, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover   1
%define libname libacars%{sover}
Name:           libacars
Version:        1.3.1
Release:        1.28
Summary:        A library for decoding various ACARS message payloads
License:        MIT
Group:          Development/Libraries/C and C++
URL:            https://github.com/szpajder/libacars
#Git-Clone:     https://github.com/szpajder/libacars.git
Source:         https://github.com/szpajder/%{name}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(zlib)

%description
libacars is a library for decoding various ACARS message payloads.

%package -n %{libname}
Summary:        A library for decoding various ACARS message payloads
Group:          System/Libraries

%description -n %{libname}
libacars is a library for decoding various ACARS message payloads.

%package devel
Summary:        Development files for libacars
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}

%description devel
libacars is a library for decoding various ACARS message payloads.

This subpackage contains libraries and header files for developing
applications that want to make use of libacars.

%package -n acars-examples
Summary:        Example applications for libacars
Group:          Productivity/Hamradio/Other

%description -n acars-examples
Example applications for for libacars:

 * decode_arinc.c - decodes ARINC-622 messages supplied at the
   command line or from a file.
 * adsc_get_position - illustrates how to extract position-related
   fields from decoded ADS-C message.
 * cpdlc_get_position - illustrates how to extract position-related
   fields from CPDLC position reports.
 * media_advisory - decodes Media Advisory messages (ACARS label SA
   reports)

%prep
%setup -q

%build
%cmake \
    -DCMAKE_INSTALL_LIBDIR:PATH=%{_lib} \
    -DCMAKE_SHARED_LINKER_FLAGS=""
%make_jobs

%install
%cmake_install
rm -rf %{buildroot}/%{_datadir}/doc

%post   -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%doc CHANGELOG.md README.md
%license LICENSE.md
%{_libdir}/libacars.so.%{sover}*

%files devel
%doc doc/API_REFERENCE.md doc/API_REFERENCE.md
%{_includedir}/libacars
%{_libdir}/libacars.so
%{_libdir}/pkgconfig/libacars.pc

%files -n acars-examples
%{_bindir}/adsc_get_position
%{_bindir}/cpdlc_get_position
%{_bindir}/decode_acars_apps
%{_bindir}/media_advisory

%changelog
* Fri Sep 20 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 1.3.1
  * Downgraded optimization level for release builds from -O3 to
  - O2 to reduce chances of similar problems for cross-platform
    builds.
* Mon Aug 26 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 1.3.0
  * JSON output support for all message types. Any protocol tree
    can be serialized into a JSON string with
    la_proto_tree_format_json() function. Functions for serializing
    each individual message type into JSON are provided as well.
    Refer to doc/API_REFERENCE.md for details.
  * decode_acars_apps application now supports both human readable
    and JSON output. To enable JSON output, set LA_JSON environment
    variable to any value. If LA_JSON is not set, the program
    displays human readable output.
  * Small bugfixes in ACARS and MIAM decoders.
* Fri Mar  1 2019 Martin Pluskal <mpluskal@suse.com>
- Small packaging adjustement - build in build phase
* Wed Feb 27 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2.0
  * Added support for decoding Media Independent Aircraft Messaging
    (MIAM - ACARS label MA) version 1 and 2. All types of MIAM
    frames are decoded, provided that they fit in a single ACARS
    message. In case of multi-fragment MIAM messages only the first
    fragment is decoded (partially) due to lack of message
    reassembly support in libacars. This will be addressed in a
    future release.
    MIAM uses DEFLATE compression, hence libacars now optionally
    depends on zlib.  If zlib is not available at the build stage,
    MIAM decompression code will be disabled and many messages
    will be left undecoded.
  * `decode_acars_apps` is a new example application. It decodes
    all ACARS applications supported by libacars. This makes
    `decode_arinc` application obsolete
  * Minor bugfixes in the build system.
- Remove patch:
  * libacars-libsuffix.patch
* Sat Jan 19 2019 mardnh@gmx.de
- Initial package, version 1.1.0
